"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoomExtended = void 0;
const uuid_1 = require("uuid");
const room_1 = require("./room");
const promises_1 = __importDefault(require("./promises"));
const constants_1 = require("./constants");
class RoomExtended extends room_1.Room {
    constructor(connection, pc, name, pin) {
        super(connection, pc, name, pin);
    }
    createRoom() {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.CREATE_ROOM, {
                name: self._name,
                pin: self._pin,
                internalMessageId: id
            });
        });
    }
    ;
    sendControlMessage(to, msg, broadcast) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.SEND_CONTROL_MESSAGE, {
                broadcast: broadcast,
                from: "",
                to: to,
                body: msg,
                internalMessageId: id
            });
        });
    }
    ;
    authorizeWaitingList(userId, authorized) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.AUTHORIZE_WAITING_LIST, {
                name: self._name,
                userId: userId,
                authorized: authorized,
                internalMessageId: id
            });
        });
    }
    ;
    moveToWaitingRoom(nickname) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.MOVE_TO_WAITING_ROOM, {
                roomName: self._name,
                nickname: nickname,
                internalMessageId: id
            });
        });
    }
    ;
    configureWaitingRoom(enabled) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.CONFIGURE_WAITING_ROOM, {
                name: self._name,
                enabled: enabled,
                internalMessageId: id
            });
        });
    }
    ;
    assignRole(nickname, role) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.ASSIGN_ROLE, {
                roomName: self._name,
                nickname: nickname,
                role: role,
                internalMessageId: id
            });
        });
    }
    ;
    subscribeToWaitingParticipant(nickname) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.SUBSCRIBE_TO_WAITING_PARTICIPANT, {
                roomName: self._name,
                nickname: nickname,
                internalMessageId: id
            });
        });
    }
    ;
    unsubscribeFromWaitingParticipant(nickname) {
        const self = this;
        return new Promise((resolve, reject) => {
            const id = (0, uuid_1.v4)();
            promises_1.default.add(id, resolve, reject);
            self.connection.send(constants_1.InternalApi.UNSUBSCRIBE_FROM_WAITING_PARTICIPANT, {
                roomName: self._name,
                nickname: nickname,
                internalMessageId: id
            });
        });
    }
    ;
}
exports.RoomExtended = RoomExtended;
//# sourceMappingURL=room-extended.js.map